@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-11-05 10:03:55
-:LastEditTime: 2020-11-24 17:25:11
+:LastEditTime: 2021-02-07 10:24:51
 :LastEditors: HuangJingCan
 :description: 机台相关
 """
@@ -28,14 +28,16 @@ class MachinieListHandler(SevenBaseHandler):
         :last_editors: HuangJingCan
         """
         app_id = self.get_taobao_param().source_app_id
-        act_id = int(self.get_param("act_id", "0"))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
+        act_id = int(self.get_param("act_id", 0))
 
-        machine_info_model = MachineInfoModel()
         condition = "act_id=%s AND app_id=%s AND is_release=1"
-        machine_info_page_list, total = machine_info_model.get_dict_page_list("*", page_index, page_size, condition, order_by="sort_index desc", params=[act_id, app_id])
+        params = [act_id, app_id]
+        order_by = "sort_index desc"
 
-        page_info = PageInfo(page_index, page_size, total, machine_info_page_list)
+        page_list, total = MachineInfoModel().get_dict_page_list("*", page_index, page_size, condition, "", order_by, params)
 
-        self.reponse_json_success(page_info)
\ No newline at end of file
+        page_info = PageInfo(page_index, page_size, total, page_list)
+
+        return self.reponse_json_success(page_info)
\ No newline at end of file
