@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-:LastEditTime: 2021-02-03 12:56:32
+:LastEditTime: 2021-02-22 15:00:50
 :LastEditors: HuangJingCan
 :description: 任务处理
 """
@@ -107,6 +107,7 @@ class TaskListHandler(TaskBaseHandler):
                 result["status"] = 1 if len(today_invite) >= user_limit else 0
                 result["user_limit"] = user_limit
                 result["invite_user_list"] = today_invite
+                result["completed_quantity"] = len(today_invite)
                 result["content"] = f"赠送+{reward_value}{last_content}"
                 result["reward"] = reward_value
                 result["type"] = "invite"
@@ -163,20 +164,13 @@ class TaskListHandler(TaskBaseHandler):
             elif task_info.task_type == 7:  #收藏
                 collect_log_model = CollectLogModel()
                 user_goods_list = collect_log_model.get_list("act_id=%s and open_id=%s", params=[act_id, open_id])
+                completed_quantity = collect_log_model.get_total("act_id=%s and open_id=%s and create_day=%s", params=[act_id, open_id, now_day])
                 result = {}
                 result["title"] = "收藏任意1个商品"
-                # goods_list = task_config["goods_list"] if task_config.__contains__("goods_list") else []
-                # user_goods_list = [str(i.goods_id) for i in user_goods_list] if len(user_goods_list) > 0 else []
-                # for good in goods_list:
-                #     if str(good["num_iid"]) in user_goods_list:
-                #         good["status"] = 1
-                #     else:
-                #         good["status"] = 0
-                # result["goods_list"] = goods_list
-                # result["user_goods_list"] = user_goods_list
                 result["goods_list"] = task_config["goods_list"] if task_config.__contains__("goods_list") else []
                 result["user_goods_list"] = [str(i.goods_id) for i in user_goods_list] if len(user_goods_list) > 0 else []
                 result["num_limit"] = int(task_config["num_limit"]) if task_config.__contains__("num_limit") else 0
+                result["completed_quantity"] = completed_quantity
                 result["content"] = f"赠送+{reward_value}{last_content}"
                 result["reward"] = reward_value
                 result["type"] = "collect"
@@ -185,20 +179,13 @@ class TaskListHandler(TaskBaseHandler):
             elif task_info.task_type == 8:  #浏览
                 browse_log_model = BrowseLogModel()
                 user_goods_list = browse_log_model.get_list("act_id=%s and open_id=%s", params=[act_id, open_id])
+                completed_quantity = browse_log_model.get_total("act_id=%s and open_id=%s and create_day=%s", params=[act_id, open_id, now_day])
                 result = {}
                 result["title"] = "浏览任意1个商品"
-                # goods_list = task_config["goods_list"] if len(task_config["goods_list"]) > 0 else []
-                # user_goods_list = [str(i.goods_id) for i in user_goods_list_model] if len(user_goods_list_model) > 0 else []
-                # for good in goods_list:
-                #     if str(good["num_iid"]) in user_goods_list:
-                #         good["status"] = 1
-                #     else:
-                #         good["status"] = 0
-                # result["goods_list"] = goods_list
-                # result["user_goods_list"] = user_goods_list
                 result["goods_list"] = task_config["goods_list"] if len(task_config["goods_list"]) > 0 else []
                 result["user_goods_list"] = [str(i.goods_id) for i in user_goods_list] if len(user_goods_list) > 0 else []
                 result["num_limit"] = int(task_config["num_limit"]) if task_config.__contains__("num_limit") else 0
+                result["completed_quantity"] = completed_quantity
                 result["content"] = f"赠送+{reward_value}{last_content}"
                 result["reward"] = reward_value
                 result["type"] = "browse"
@@ -514,7 +501,6 @@ class InviteHandler(TaskBaseHandler):
         """
         open_id = self.get_taobao_param().open_id
         app_id = self.get_taobao_param().source_app_id
-        login_token = self.get_param("login_token")
         act_id = int(self.get_param("act_id", 0))
         invite_open_id = self.get_param("invite_open_id")
         is_task = int(self.get_param("is_task", 1))
@@ -618,13 +604,21 @@ class InviteRewardHandler(TaskBaseHandler):
             log_info["title"] = f"邀请{today_invite_count}人"
             log_info["invite_list"] = today_invite_list if today_invite_count > 0 else []
             log_title = f"邀请+{reward_count}{last_content}"
-            update_sql = f"lottery_value=lottery_value+{reward_count}"
+            # update_sql = f"lottery_value=lottery_value+{reward_count}"
             invite_user_nick_list = [i['invite_user_nick'] for i in today_invite_list]
             log_desc = "被邀请用户：" + ",".join(invite_user_nick_list)
+            #判断活动的抽奖货币类型来选择更新字段
+            if act_dict['currency_type'] == 1:
+                user_info.lottery_value = user_info.lottery_value + reward_count
+                update_sql = f"lottery_value=lottery_value+{reward_count}"
+            elif act_dict['currency_type'] == 2:
+                user_info.surplus_integral = user_info.surplus_integral + reward_count
+                update_sql = f"surplus_integral=surplus_integral+{reward_count}"
             send_result = self.send_lottery_value(log_title, user_info, update_sql, reward_count, act_dict, 2, 203, log_info, log_desc)
             if send_result == False:
                 return self.reponse_json_error("Error", "邀请成功,系统异常未给奖励")
             invite_log_model.update_table("is_handle=1", SevenHelper.get_condition_by_id_list("id", [i['id'] for i in today_invite_list]))
+
             behavior_model = BehaviorModel()
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'InviteUserCount', 1, act_dict['act_type'])
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'InviteCount', 1, act_dict['act_type'])
@@ -674,13 +668,21 @@ class FollowHandler(TaskBaseHandler):
         send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
         if send_num > 0:
             user_info.is_favor = 1
-            user_info.lottery_value = user_info.lottery_value + send_num
+            # user_info.lottery_value = user_info.lottery_value + send_num
             last_content = self.get_currency_type_name(act_dict['currency_type'])
             log_title = f"关注店铺+{send_num}{last_content}"
-            update_sql = f"lottery_value=lottery_value+{send_num},is_favor=1"
+            # update_sql = f"lottery_value=lottery_value+{send_num},is_favor=1"
+            #判断活动的抽奖货币类型来选择更新字段
+            if act_dict['currency_type'] == 1:
+                user_info.lottery_value = user_info.lottery_value + send_num
+                update_sql = f"lottery_value=lottery_value+{send_num},is_favor=1"
+            elif act_dict['currency_type'] == 2:
+                user_info.surplus_integral = user_info.surplus_integral + send_num
+                update_sql = f"surplus_integral=surplus_integral+{send_num},is_favor=1"
             send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 204)
             if send_result == False:
                 return self.reponse_json_error("Error", "关注店铺成功,系统异常未给奖励")
+
             behavior_model = BehaviorModel()
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'FollowUserCount', 1, act_dict['act_type'])
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'FollowCount', 1, act_dict['act_type'])
@@ -736,13 +738,21 @@ class JoinMemberRewardHandler(TaskBaseHandler):
         send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
         if send_num > 0:
             user_info.is_member = 1
-            user_info.lottery_value = user_info.lottery_value + send_num
+            # user_info.lottery_value = user_info.lottery_value + send_num
             last_content = self.get_currency_type_name(act_dict['currency_type'])
             log_title = f"加入会员+{send_num}{last_content}"
-            update_sql = f"lottery_value=lottery_value+{send_num},is_member=1"
+            # update_sql = f"lottery_value=lottery_value+{send_num},is_member=1"
+            #判断活动的抽奖货币类型来选择更新字段
+            if act_dict['currency_type'] == 1:
+                user_info.lottery_value = user_info.lottery_value + send_num
+                update_sql = f"lottery_value=lottery_value+{send_num},is_member=1"
+            elif act_dict['currency_type'] == 2:
+                user_info.surplus_integral = user_info.surplus_integral + send_num
+                update_sql = f"surplus_integral=surplus_integral+{send_num},is_member=1"
             send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 205)
             if send_result == False:
                 return self.reponse_json_error("Error", "加入会员成功,系统异常未给奖励")
+
             behavior_model = BehaviorModel()
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'MemberUserCount', 1, act_dict['act_type'])
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'MemberCount', 1, act_dict['act_type'])
@@ -820,18 +830,26 @@ class CollectGoodsHandler(TaskBaseHandler):
 
         send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
         if send_num > 0:
-            user_info.lottery_value = user_info.lottery_value + send_num
+            # user_info.lottery_value = user_info.lottery_value + send_num
             last_content = self.get_currency_type_name(act_dict['currency_type'])
             log_info = {}
             log_info["title"] = f"商品ID：{str(goods_id)}"
             log_info["goods_id"] = goods_id
             log_info["goods_name"] = goods_name
             log_title = f"收藏商品+{send_num}{last_content}"
-            update_sql = f"lottery_value=lottery_value+{send_num}"
+            # update_sql = f"lottery_value=lottery_value+{send_num}"
+            #判断活动的抽奖货币类型来选择更新字段
+            if act_dict['currency_type'] == 1:
+                user_info.lottery_value = user_info.lottery_value + send_num
+                update_sql = f"lottery_value=lottery_value+{send_num}"
+            elif act_dict['currency_type'] == 2:
+                user_info.surplus_integral = user_info.surplus_integral + send_num
+                update_sql = f"surplus_integral=surplus_integral+{send_num}"
             log_desc = log_info["title"]
             send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 207, log_info, log_desc)
             if send_result == False:
                 return self.reponse_json_error("Error", "对不起，请稍后再试")
+
             behavior_model = BehaviorModel()
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'CollectUserCount', 1, act_dict['act_type'])
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'CollectCount', 1, act_dict['act_type'])
@@ -923,18 +941,26 @@ class BrowseGoodsHandler(TaskBaseHandler):
 
         send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
         if send_num > 0:
-            user_info.lottery_value = user_info.lottery_value + send_num
+            # user_info.lottery_value = user_info.lottery_value + send_num
             last_content = self.get_currency_type_name(act_dict['currency_type'])
             log_info = {}
             log_info["title"] = f"商品ID：{str(goods_id)}"
             log_info["goods_id"] = goods_id
             log_info["goods_name"] = goods_name
             log_title = f"浏览商品+{send_num}{last_content}"
-            update_sql = f"lottery_value=lottery_value+{send_num}"
+            # update_sql = f"lottery_value=lottery_value+{send_num}"
+            #判断活动的抽奖货币类型来选择更新字段
+            if act_dict['currency_type'] == 1:
+                user_info.lottery_value = user_info.lottery_value + send_num
+                update_sql = f"lottery_value=lottery_value+{send_num}"
+            elif act_dict['currency_type'] == 2:
+                user_info.surplus_integral = user_info.surplus_integral + send_num
+                update_sql = f"surplus_integral=surplus_integral+{send_num}"
             log_desc = log_info["title"]
             send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 208, log_info, log_desc)
             if send_result == False:
                 return self.reponse_json_error("Error", "对不起，请稍后再试")
+
             behavior_model = BehaviorModel()
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'BrowseUserCount', 1, act_dict['act_type'])
             behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'BrowseCount', 1, act_dict['act_type'])
