@@ -2,7 +2,7 @@
 """
 :Author: CaiYouBin
 :Date: 2020-05-26 17:38:03
-:LastEditTime: 2020-12-30 18:13:47
+:LastEditTime: 2021-02-07 12:53:17
 :LastEditors: HuangJingCan
 :description: 主题皮肤相关
 """
@@ -27,30 +27,31 @@ class ThemeInfoHandler(SevenBaseHandler):
         :return 主题信息
         :last_editors: HuangJingCan
         """
-        act_id = int(self.get_param("act_id"))
+        act_id = int(self.get_param("act_id", 0))
         ver_no = self.get_param("ver_no")
         act_info_model = ActInfoModel()
         theme_info_model = ThemeInfoModel()
 
-        act_info = act_info_model.get_entity("id=%s", params=act_id)
-        if act_info:
-            theme_info = theme_info_model.get_dict("id=%s", params=act_info.theme_id)
-            if not theme_info:
-                return self.reponse_json_error("NoTheme", "对不起，找不到该主题")
-            out_id = theme_info["out_id"]
-            if ver_no:
-                theme_ver_model = ThemeVerModel()
-                theme_ver = theme_ver_model.get_entity("out_id=%s and ver_no=%s", params=[out_id, ver_no])
-                if theme_ver and theme_ver.client_json != "":
-                    theme_info["client_json"] = theme_ver.client_json
-            skin_info_model = SkinInfoModel()
-            skin_info_list = skin_info_model.get_dict_list("theme_id=%s", params=act_info.theme_id)
+        act_dict = act_info_model.get_dict_by_id(act_id)
+        if not act_dict:
+            return self.reponse_json_error("NoAct", "对不起，找不到该活动")
 
-            theme_info["skin_list"] = skin_info_list
+        theme_id = act_dict["theme_id"]
+        theme_info = theme_info_model.get_dict("id=%s", params=theme_id)
+        if not theme_info:
+            return self.reponse_json_error("NoTheme", "对不起，找不到该主题")
 
-            self.reponse_json_success(theme_info)
-        else:
-            self.reponse_json_error("NoAct", "对不起，找不到该活动")
+        out_id = theme_info["out_id"]
+        if ver_no:
+            theme_ver = ThemeVerModel().get_entity("out_id=%s and ver_no=%s", params=[out_id, ver_no])
+            if theme_ver and theme_ver.client_json != "":
+                theme_info["client_json"] = theme_ver.client_json
+
+        skin_info_list = SkinInfoModel().get_dict_list("theme_id=%s", params=theme_id)
+
+        theme_info["skin_list"] = skin_info_list
+
+        self.reponse_json_success(theme_info)
 
 
 class ThemeSaveHandler(SevenBaseHandler):
@@ -71,12 +72,12 @@ class ThemeSaveHandler(SevenBaseHandler):
         :last_editors: HuangJingCan
         """
         app_id = self.get_param("app_id")
-        # 1 新增  2修改
         theme_name = self.get_param("theme_name")
         client_json = self.get_param("client_json")
         server_json = self.get_param("server_json")
         out_id = self.get_param("out_id")
         ver_no = self.get_param("ver_no")
+
         theme_info_model = ThemeInfoModel()
         theme_ver_model = ThemeVerModel()
         theme_info = theme_info_model.get_entity("out_id=%s", params=out_id)
