@@ -2,10 +2,11 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-24 17:26:33
-:LastEditTime: 2021-01-20 17:16:42
+:LastEditTime: 2021-02-08 10:57:29
 :LastEditors: HuangJingCan
 :description: App相关
 """
+from copy import deepcopy
 from seven_cloudapp.handlers.top_base import *
 
 from seven_cloudapp.models.enum import *
@@ -242,12 +243,33 @@ class AppUpdateHandler(TopBaseHandler):
     @filter_check_params()
     def get_async(self):
         """
-        :description: 前端版本更新(请求top接口)
-        :param {type} 
+        :description: 前端版本更新
+        :param app_id:app_id
         :return: 
         :last_editors: HuangJingCan
         """
-        self.app_update()
+        app_id = self.get_param("app_id")
+        client_template_id = config.get_value("client_template_id")
+        test_client_ver = config.get_value("test_client_ver")
+        access_token = self.get_taobao_param().access_token
+
+        base_info = BaseInfoModel().get_entity()
+        client_ver = base_info.client_ver
+
+        app_info = AppInfoModel().get_entity("app_id=%s", params=app_id)
+        if not app_info:
+            return self.reponse_json_error("NoApp", "对不起，找不到该APP")
+
+        old_app_info = deepcopy(app_info)
+
+        #指定账号升级
+        if test_client_ver:
+            user_nick = self.get_taobao_param().user_nick
+            if user_nick:
+                if user_nick == config.get_value("test_user_nick"):
+                    client_ver = test_client_ver
+
+        self.app_update(app_id, client_template_id, client_ver, access_token, app_info, old_app_info)
 
 
 class AppInfoHandler(TopBaseHandler):
