@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-29 09:40:42
-:LastEditTime: 2021-01-05 08:21:51
+:LastEditTime: 2021-02-08 11:34:05
 :LastEditors: HuangJingCan
 :description: 机台（盒子）
 """
@@ -10,21 +10,19 @@ import decimal
 import copy
 from seven_cloudapp.handlers.seven_base import *
 
-from seven_cloudapp.models.enum import OperationType, SourceType
+from seven_cloudapp.models.enum import *
 from seven_cloudapp.models.seven_model import PageInfo
 from seven_cloudapp.models.behavior_model import *
-from seven_cloudapp.models.throw_model import *
 from seven_cloudapp.models.db_models.machine.machine_info_model import *
 from seven_cloudapp.models.db_models.machine.machine_value_model import *
 from seven_cloudapp.models.db_models.machine.machine_value_log_model import *
-from seven_cloudapp.models.db_models.act.act_prize_model import *
 from seven_cloudapp.models.db_models.behavior.behavior_log_model import *
 from seven_cloudapp.models.db_models.behavior.behavior_orm_model import *
 from seven_cloudapp.models.db_models.behavior.behavior_report_model import *
 from seven_cloudapp.models.db_models.coin.coin_order_model import *
 from seven_cloudapp.models.db_models.user.user_info_model import *
 from seven_cloudapp.models.db_models.act.act_info_model import *
-from seven_cloudapp.models.db_models.throw.throw_goods_model import *
+from seven_cloudapp.models.db_models.act.act_prize_model import *
 
 
 class MachineHandler(SevenBaseHandler):
@@ -45,19 +43,30 @@ class MachineHandler(SevenBaseHandler):
 
 class MachineListHandler(SevenBaseHandler):
     """
-    :description: 获取机台列表（业务各自实现）
+    :Description: 机台信息
     """
     @filter_check_params("act_id")
     def get_async(self):
         """
-        :description: 获取机台列表（业务各自实现）
+        :Description: 获取机台列表
         :param act_id：活动id
         :param page_index：页索引
         :param page_size：页大小
-        :return: 列表
+        :return: list
         :last_editors: HuangJingCan
         """
-        pass
+        act_id = int(self.get_param("act_id", 0))
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 10))
+
+        if act_id <= 0:
+            return self.reponse_json_error_params()
+
+        page_list, total = MachineInfoModel().get_dict_page_list("*", page_index, page_size, "act_id=%s", "", "sort_index desc", act_id)
+
+        page_info = PageInfo(page_index, page_size, total, page_list)
+
+        self.reponse_json_success(page_info)
 
 
 class MachineDelHandler(SevenBaseHandler):
@@ -69,7 +78,7 @@ class MachineDelHandler(SevenBaseHandler):
         """
         :description: 删除机台
         :param machine_id：机台id
-        :return: 
+        :return: reponse_json_success
         :last_editors: HuangJingCan
         """
         machine_id = int(self.get_param("machine_id", 0))
@@ -77,8 +86,6 @@ class MachineDelHandler(SevenBaseHandler):
         if machine_id <= 0:
             return self.reponse_json_error_params()
 
-        machine = MachineInfoModel().get_dict('id=%s', params=machine_id)
-
         ActPrizeModel().del_entity("machine_id=%s", machine_id)
 
         MachineInfoModel().del_entity("id=%s", machine_id)
@@ -87,8 +94,6 @@ class MachineDelHandler(SevenBaseHandler):
 
         BehaviorOrmModel().del_entity("key_name='openUserCount_" + str(machine_id) + "' or key_name='openCount_" + str(machine_id) + "'")
 
-        ThrowModel().throw_goods_update(machine['act_id'], machine['goods_id'], self.get_now_datetime())
-
         self.create_operation_log(OperationType.delete.value, "machine_info_tb", "MachineDelHandler", None, machine_id)
 
         self.reponse_json_success()
@@ -139,7 +144,7 @@ class MachineValueLogHandler(SevenBaseHandler):
         machine_value_log_model = MachineValueLogModel()
 
         machine_info_list = machine_info_model.get_list("act_id=%s", params=act_id)
-        machine_value_log_list_dict = machine_value_log_model.get_dict_list("act_id=%s and open_id=%s", order_by='create_date desc', params=[act_id, user_open_id])
+        machine_value_log_list_dict = machine_value_log_model.get_dict_list("act_id=%s and open_id=%s", order_by='id desc', params=[act_id, user_open_id])
         machine_value_list = machine_value_model.get_list("act_id=%s and open_id=%s", params=[act_id, user_open_id])
 
         machine_value_log_groups = []
