@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-:LastEditTime: 2021-01-28 10:26:31
+:LastEditTime: 2021-02-03 10:15:12
 :LastEditors: HuangJingCan
 :description: 订单相关
 """
@@ -290,7 +290,9 @@ class PrizeOrderExportHandler(SevenBaseHandler):
         order_no = self.get_param("order_no")
         order_status = int(self.get_param("order_status", -1))
         user_nick = self.get_param("nick_name")
-        is_machine = int(self.get_param("is_machine", 0))
+        real_name = self.get_param("real_name")
+        # 0-没关联机台或者价格挡位，1-关联机台，2-关联价格挡位
+        is_machine_gear = config.get_value("is_machine_gear", 0)
 
         condition = "act_id=%s"
         params = [act_id]
@@ -301,6 +303,9 @@ class PrizeOrderExportHandler(SevenBaseHandler):
         if user_nick != "":
             params.append(user_nick)
             condition += " AND user_nick=%s"
+        if real_name:
+            condition += " AND real_name=%s"
+            params.append(real_name)
         if order_status >= 0:
             params.append(order_status)
             condition += " AND order_status=%s"
@@ -322,7 +327,7 @@ class PrizeOrderExportHandler(SevenBaseHandler):
                     data_row["小程序订单号"] = prize_order["order_no"]
                     data_row["淘宝子订单号"] = prize_roster["order_no"]
                     data_row["淘宝名"] = prize_order["user_nick"]
-                    if is_machine == 1:
+                    if is_machine_gear in (1, 2):
                         data_row["盒子名称"] = prize_roster["machine_name"]
                         data_row["盒子价格"] = str(prize_roster["machine_price"])
                     data_row["奖品名称"] = prize_roster["prize_name"]
@@ -453,7 +458,8 @@ class PrizeRosterExportHandler(SevenBaseHandler):
         order_no = self.get_param("order_no")
         order_status = int(self.get_param("order_status", -1))
         user_nick = self.get_param("nick_name")
-        is_machine = int(self.get_param("is_machine", 0))
+        # 0-没关联机台或者价格挡位，1-关联机台，2-关联价格挡位
+        is_machine_gear = config.get_value("is_machine_gear", 0)
 
         condition = "act_id=%s"
         params = [act_id]
@@ -478,7 +484,7 @@ class PrizeRosterExportHandler(SevenBaseHandler):
             data_row["行为编号"] = prize_roster["id"]
             data_row["淘宝子订单号"] = prize_roster["order_no"]
             data_row["淘宝名"] = prize_roster["user_nick"]
-            if is_machine == 1:
+            if is_machine_gear in (1, 2):
                 data_row["盒子名称"] = prize_roster["machine_name"]
                 data_row["盒子价格"] = str(prize_roster["machine_price"])
             data_row["奖品名称"] = prize_roster["prize_name"]
