@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-12 20:04:54
-:LastEditTime: 2021-02-06 10:25:57
+:LastEditTime: 2021-02-08 14:53:55
 :LastEditors: HuangJingCan
 :description: 用户相关
 """
@@ -37,7 +37,6 @@ class LoginHandler(SevenBaseHandler):
         """
         open_id = self.get_taobao_param().open_id
         user_nick = self.get_taobao_param().user_nick
-        source_app_id = self.get_taobao_param().source_app_id
 
         request_params = str(self.request_params)
 
@@ -82,7 +81,7 @@ class UserStatusHandler(SevenBaseHandler):
         :description: 更新用户状态
         :param userid：用户id
         :param user_state：用户状态
-        :return: reponse_json_success
+        :return: 
         :last_editors: HuangJingCan
         """
         user_id = int(self.get_param("userid"))
@@ -97,15 +96,14 @@ class UserStatusHandler(SevenBaseHandler):
 
 class UserStatusByBlackHandler(SevenBaseHandler):
     """
-    :description: 更新用户状态
+    :description: 更新用户状态(拉黑)
     """
     @filter_check_params("userid")
     def get_async(self):
         """
-        :description: 更新用户状态
+        :description: 更新用户状态(拉黑)
         :param userid：用户id
-        :param user_state：用户状态
-        :return: reponse_json_success
+        :return: 
         :last_editors: LaiKaiXiang
         """
         user_id = int(self.get_param("userid"), 0)
@@ -186,10 +184,10 @@ class UserListHandler(SevenBaseHandler):
         page_list, total = UserInfoModel().get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
 
         if is_integral == 1:
-            act_info = ActInfoModel().get_entity("id=%s", params=act_id)
-            if act_info:
+            act_dict = ActInfoModel().get_dict_by_id(act_id)
+            if act_dict:
                 for user_info in page_list:
-                    user_info['lottery_value'] = user_info['surplus_integral'] // act_info.lottery_value
+                    user_info['lottery_value'] = user_info['surplus_integral'] // act_dict['lottery_value']
 
         page_info = PageInfo(page_index, page_size, total, page_list)
 
@@ -216,6 +214,7 @@ class UserListExportHandler(SevenBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         user_nick = self.get_param("nick_name")
         user_state = int(self.get_param("user_state", -1))
+
         condition = "act_id=%s"
         params = [act_id]
 
@@ -319,6 +318,10 @@ class UserBlackListHandler(SevenBaseHandler):
         """
         :description: 获取黑名单管理列表
         :param act_id：act_id
+        :param audit_status：状态
+        :param nick_name：用户昵称
+        :param create_date_start：创建时间开始
+        :param create_date_end：创建时间结束
         :return: list
         :last_editors: HuangJingCan
         """
@@ -478,6 +481,8 @@ class LotteryValueLogHandler(SevenBaseHandler):
         :param nick_name：淘宝名
         :param start_date：开始时间
         :param end_date：结束时间
+        :param source_type：来源类型
+        :param user_open_id：用户open_id
         :return list
         :last_editors: HuangJingCan
         """
