@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-08-12 09:06:24
-:LastEditTime: 2021-02-03 12:56:16
+:LastEditTime: 2021-02-08 10:52:22
 :LastEditors: HuangJingCan
 :description: 淘宝top接口基础类
 """
@@ -658,34 +658,18 @@ class TopBaseHandler(SevenBaseHandler):
                     if "submsg=" in content:
                         return self.reponse_json_error("Error", content[len("submsg="):])
 
-    def app_update(self):
+    def app_update(self, app_id, client_template_id, client_ver, access_token, app_info, old_app_info):
         """
         :description: app更新
-        :param 
+        :param app_id:app_id
+        :param client_template_id:client_template_id
+        :param client_ver:client_ver
+        :param access_token:access_token
+        :param app_info:app_info
+        :param old_app_info:old_app_info
         :return 
         :last_editors: HuangJingCan
         """
-        app_id = self.get_param("app_id")
-        client_template_id = config.get_value("client_template_id")
-        test_client_ver = config.get_value("test_client_ver")
-        access_token = self.get_taobao_param().access_token
-
-        base_info = BaseInfoModel().get_entity()
-        client_ver = base_info.client_ver
-
-        app_info_model = AppInfoModel()
-        app_info = app_info_model.get_entity("app_id=%s", params=app_id)
-        if not app_info:
-            return self.reponse_json_error("NoApp", "对不起，找不到该APP")
-        old_app_info = app_info
-
-        #指定账号升级
-        if test_client_ver:
-            user_nick = self.get_taobao_param().user_nick
-            if user_nick:
-                if user_nick == config.get_value("test_user_nick"):
-                    client_ver = test_client_ver
-
         try:
             top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
             req = top.api.MiniappTemplateUpdateappRequest()
@@ -703,10 +687,9 @@ class TopBaseHandler(SevenBaseHandler):
                     app_info.app_ver = resp["miniapp_template_updateapp_response"]["app_version"]
                     app_info.template_ver = client_ver
                     app_info.modify_date = self.get_now_datetime()
-                    app_info_model.update_entity(app_info)
-
-            # self.logger_info.info(str(resp) + "【更新】")
-            self.create_operation_log(OperationType.update.value, app_info.__str__(), "AppUpdateHandler", self.json_dumps(old_app_info), self.json_dumps(app_info))
+                    AppInfoModel().update_entity(app_info)
+                    # self.logger_info.info(str(resp) + "【更新】")
+                    self.create_operation_log(OperationType.update.value, app_info.__str__(), "AppUpdateHandler", self.json_dumps(old_app_info), self.json_dumps(app_info))
             return self.reponse_json_success()
         except Exception as ex:
             if "submsg" in str(ex):
@@ -830,6 +813,32 @@ class TopBaseHandler(SevenBaseHandler):
                     if "submsg=" in content:
                         return self.reponse_json_error("Error", content[len("submsg="):])
 
+    def benefit_send(self, right_ename, open_id, access_token):
+        """
+        :description: 发奖接口(请求top接口)
+        :param right_ename:奖池ID
+        :param open_id:open_id
+        :param access_token:access_token
+        :return: dict
+        :last_editors: HuangJianYi
+        """
+        resp = {}
+        try:
+            # if self.get_is_test() == True:
+            #     return {"alibaba_benefit_send_response": {"result_msg": "发放成功", "result_code": "SEND_SUCCESS", "result_success": True, "right_id": 891033, "prize_name": "广陌测试虚拟奖品"}}
+            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
+            req = top.api.AlibabaBenefitSendRequest()
+            req.right_ename = right_ename
+            req.receiver_id = open_id
+            req.user_type = "taobao"
+            req.unique_id = str(open_id) + str(right_ename) + str(TimeHelper.get_now_timestamp())
+            req.app_name = "promotioncenter-" + config.get_value("server_template_id")
+            resp = req.getResponse(access_token)
+            return resp
+        except Exception as ex:
+            self.logger_error.error(str(ex) + "【获取优惠券发奖top接口】")
+            return {}
+
     def get_member_info(self, access_token):
         """
         :description: 获取top接口淘宝会员信息
