@@ -39,6 +39,7 @@ class ActPrize:
         self.prize_type = 0  # 奖品类型（1实物2店铺商品3优惠券4参与奖5谢谢参与）
         self.prize_price = 0  # 奖品价格
         self.probability = 0  # 奖品权重
+        self.chance = 0  # 概率
         self.surplus = 0  # 奖品库存
         self.is_surplus = 0  # 是否显示奖品库存（1显示0-不显示）
         self.is_prize_notice = 0  # 是否显示中奖跑马灯
@@ -46,6 +47,7 @@ class ActPrize:
         self.prize_total = 0  # 奖品总数
         self.lottery_type = 0  # 出奖类型（1概率出奖 2强制概率）
         self.force_count = 0  # 每几件出一件
+        self.force_start = 0  # 多少件后才能被抽出
         self.tag_name = ""  # 商品标签
         self.tag_id = 0  # 标签ID
         self.hand_out = 0  # 已发出数量
@@ -59,7 +61,7 @@ class ActPrize:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'act_id', 'award_id', 'app_id', 'owner_open_id', 'machine_id', 'ascription_type', 'prize_name', 'prize_title', 'prize_pic', 'prize_detail', 'goods_id', 'goods_code', 'goods_code_list', 'coupon_type', 'right_ename', 'pool_id', 'coupon_start_date', 'coupon_end_date', 'prize_type', 'prize_price', 'probability', 'surplus', 'is_surplus', 'is_prize_notice', 'prize_limit', 'prize_total', 'lottery_type', 'force_count', 'tag_name', 'tag_id', 'hand_out', 'is_sku', 'sort_index', 'is_release', 'sku_detail', 'lottery_sum', 'create_date', 'modify_date']
+        return ['id', 'act_id', 'award_id', 'app_id', 'owner_open_id', 'machine_id', 'ascription_type', 'prize_name', 'prize_title', 'prize_pic', 'prize_detail', 'goods_id', 'goods_code', 'goods_code_list', 'coupon_type', 'right_ename', 'pool_id', 'coupon_start_date', 'coupon_end_date', 'prize_type', 'prize_price', 'probability', 'chance', 'surplus', 'is_surplus', 'is_prize_notice', 'prize_limit', 'prize_total', 'lottery_type', 'force_count', 'force_start', 'tag_name', 'tag_id', 'hand_out', 'is_sku', 'sort_index', 'is_release', 'sku_detail', 'lottery_sum', 'create_date', 'modify_date']
         
     @classmethod
     def get_primary_key(self):
